@@ -2,10 +2,13 @@ from functools import partial
 import random
 import copy
 from typing import List, Union, Optional
+import logging
 
 from .utils import bpm_to_time, note_to_midi
 from .chord import midi_chord
 
+log = logging.getLogger(__name__)
+
 
 def _random_chance(prob):
     return random.randint(1, 100) <= prob
@@ -418,7 +421,7 @@ def midi_arp(
 
     # clamp note_duration to beat_duration
     if note_duration > beat_duration:
-        print(
+        log.warning(
             f"WARNING: note_duration {note_duration} is greater than {beat_duration}, "
         )
         note_duration = copy.copy(beat_duration)
